__version__='0.0.2'

class viewport:

    def __init__(self, world_bounds=(0, 1, 0, 1), view_bounds=(-1, 1, -1, 1)):
        Wb, Wt, Wl, Wr = world_bounds
        Vb, Vt, Vl, Vr = view_bounds

        self.Sx = ( Vr - Vl ) / ( Wr - Wl )
        self.Sy = ( Vt - Vb ) / ( Wt - Wb );
        self.Tx = ( Vl * Wr - Wl * Vr ) / ( Wr - Wl );
        self.Ty = ( Vb * Wt - Wb * Vt ) / ( Wt - Wb );

    def Dx( self, x ):
        return self.Sx * x + self.Tx

    def Dy( self, y ):
        return self.Sy * y + self.Ty



from setuptools import setup, find_packages
from window.viewport import viewport

setup(
    name='window-viewport',
    version='0.0.2',
    description='Just another window to viewport coordinates translator',
    author='Jeff Anderson',
    author_email='jeffa@cpan.org',
    url='https://github.com/jeffa/window-viewport',
    license='Artistic',
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    classifiers=[
        "Topic :: Scientific/Engineering :: Visualization",
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: Artistic License",
    ],
    long_description="Translate real world coordinates into any viewport coordinates"
)
